/v1/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »

# /v1/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture

Contents

- /v1/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture
  - POST /v1/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture
    - Parameters
    - Response status codes
    - Input
    - Sample session

## POST /v1/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:d+}/ports/{port_number:d+}/start_capture

Start a packet capture on a IOU VM instance

### Parameters

- project_id: UUID for the project
- adapter_number: Adapter to start a packet capture
- vm_id: UUID for the instance
- port_number: Port on the adapter

### Response status codes

- 200: Capture started
- 400: Invalid request
- 404: Instance doesn’t exist

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
capture_file_name | ✔ | string | Capture file name
data_link_type | ✔ | string | PCAP data link type

### Sample session

    curl -i -X POST 'http://localhost:8000/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:\d+}/ports/{port_number:\d+}/start_capture' -d '{"capture_file_name": "test.pcap", "data_link_type": "DLT_EN10MB"}'

    POST /projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:\d+}/ports/{port_number:\d+}/start_capture HTTP/1.1
    {
        "capture_file_name": "test.pcap",
        "data_link_type": "DLT_EN10MB"
    }

    HTTP/1.1 200
    CONNECTION: keep-alive
    CONTENT-LENGTH: 158
    CONTENT-TYPE: application/json
    DATE: Thu, 08 Jan 2015 16:09:15 GMT
    SERVER: Python/3.4 GNS3/1.3.dev1
    X-ROUTE: /v1/projects/{project_id}/iou/vms/{vm_id}/adapters/{adapter_number:\d+}/ports/{port_number:\d+}/start_capture

    {
        "pcap_file_path": "/var/folders/3s/r2wbv07n7wg4vrsn874lmxxh0000gn/T/tmpd25gn8du/a1e920ca-338a-4e9f-b363-aa607b09dd80/project-files/captures/test.pcap"
    }

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Iou »